The HTTP API Documentation extension - Betty 0.4.0a3 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# The HTTP API Documentation extension

The `betty.extension.HttpApiDoc` extension renders interactive and user-friendly HTTP API documentation using ReDoc.

Important

This extension requires npm.

Enable this extension in your project’s configuration file as follows:

YAML

    extensions:
      betty.extension.HttpApiDoc: {}

JSON

    {
      "extensions": {
        "betty.extension.HttpApiDoc": {}
      }
    }

## Configuration

This extension is not configurable.